@@ -69,6 +69,9 @@ liq_error_stuff[] = {
     {LIQ_BUFFER_TOO_SMALL, "buffer too small"},
     {LIQ_INVALID_POINTER, "invalid pointer"},
     {LIQ_HISTOGRAM_FAILED, "get_histogram failed"},
+    {LIQ_FREED_POINTER, "bad access to freed pointer"},
+    {LIQ_NULL_POINTER, "null pointer"},
+    {LIQ_BAD_POINTER, "pointer with wrong type"},
 };
 
 #define N_LIQ_ERRORS (sizeof (liq_error_stuff) / sizeof (struct liq_error_c))
@@ -267,6 +270,14 @@ image_quantize_png_quantize (image_quantize_t * iq)
 
     /* Quantize the buffer. */
 
+    error = liq_invalid_attr (iq->attr);
+    if (error != LIQ_OK) {
+	image_quantize_error (iq, error, "invalid liq_attr");
+    }
+    error = liq_invalid_image (iq->image);
+    if (error != LIQ_OK) {
+	image_quantize_error (iq, error, "invalid liq_image");
+    }
     error = liq_quantize_image_2 (iq->attr, iq->image, & iq->result);
     if (error != LIQ_OK) {
 	image_quantize_error (iq, error, "liq_quantize_image failed");
