@@ -188,6 +188,68 @@ LIQ_EXPORT bool liq_crash_if_invalid_pointer_given(void *pointer)
     return test_access || true;
 }
 
+LIQ_EXPORT liq_error liq_invalid_any (void * any)
+{
+    char test_access;
+
+    if (! any) {
+	return LIQ_NULL_POINTER;
+    }
+    test_access = *((volatile char *)any);
+    if (! test_access) {
+	return LIQ_BAD_POINTER;
+    }
+    return LIQ_OK;
+}
+
+LIQ_EXPORT liq_error liq_invalid_attr (liq_attr * attr)
+{
+    liq_error error;
+    error = liq_invalid_any (attr);
+    if (error != LIQ_OK) {
+	return error;
+    }
+    if (attr->magic_header == liq_freed_magic) {
+	return LIQ_FREED_POINTER;
+    }
+    if (attr->magic_header != liq_attr_magic) {
+	return LIQ_INVALID_POINTER;
+    }
+    return LIQ_OK;
+}
+
+LIQ_EXPORT liq_error liq_invalid_image (liq_image * image)
+{
+    liq_error error;
+    error = liq_invalid_any (image);
+    if (error) {
+	return error;
+    }
+    if (image->magic_header == liq_freed_magic) {
+	return LIQ_FREED_POINTER;
+    }
+    if (image->magic_header != liq_image_magic) {
+	return LIQ_INVALID_POINTER;
+    }
+    return LIQ_OK;
+}
+
+LIQ_EXPORT liq_error liq_invalid_result (liq_result * result)
+{
+    liq_error error;
+    error = liq_invalid_any (result);
+    if (error) {
+	return error;
+    }
+    if (result->magic_header == liq_freed_magic) {
+	return LIQ_FREED_POINTER;
+    }
+    if (result->magic_header != liq_result_magic) {
+	return LIQ_INVALID_POINTER;
+    }
+    return LIQ_OK;
+}
+
 static double quality_to_mse(long quality)
 {
     if (quality == 0) return MAX_DIFF;
