@@ -44,10 +44,17 @@ typedef enum liq_error {
     LIQ_BUFFER_TOO_SMALL,
     LIQ_INVALID_POINTER,
     LIQ_HISTOGRAM_FAILED,
+    LIQ_FREED_POINTER,
+    LIQ_NULL_POINTER,
+    LIQ_BAD_POINTER,
 } liq_error;
 
 enum liq_ownership {LIQ_OWN_ROWS=4, LIQ_OWN_PIXELS=8};
 
+LIQ_EXPORT liq_error liq_invalid_attr (liq_attr *);
+LIQ_EXPORT liq_error liq_invalid_image (liq_image *);
+LIQ_EXPORT liq_error liq_invalid_result (liq_result *);
+
 LIQ_EXPORT liq_attr* liq_attr_create(void);
 LIQ_EXPORT liq_attr* liq_attr_create_with_allocator(void* (*malloc)(size_t), void (*free)(void*));
 LIQ_EXPORT liq_attr* liq_attr_copy(liq_attr *orig);
